

Dominos_BuffTimes.defaults = {
	-- defaults for ignored de/buffs
	["ignored"] = {
		["WARRIOR"] = {'mortal strike'},
		["PALADIN"] = {'judgement of light'},
	}, 
	
	-- defaults for buffs that show only for your spells
	["yourbuffs"] = {
		["PRIEST"] = {"renew"},
		["DRUID"] = {"rejuvenation"},
	},
	
	-- defaults for buffs that show for any caster
	["alldebuffs"] = {
		["WARLOCK"] = {'banish', 'fear'}
	},
	
	-- defaults for buffs that show only if casted on self
	["selfbuffs"] = {
		-- classes
		["WARRIOR"] = {'shield wall', 'berserker rage',
					   'recklessness', 'spell reflection', 
					   'enraged regeneration', 'sweeping strikes', 'bladestorm',
					   'last stand'},
					   
		["DEATHKNIGHT"] = {'icebound fortitude', 'anti-magic shell', 
						   'vampiric blood', 'dancing rune weapon', 'lichborne',
						   'bone shield'},
						   
		["DRUID"] = {'berserk', 'survival instincts', 'tiger\'s fury', 'dash', 
					 'barkskin'},
					 
		["HUNTER"] = {'deterrence', 'rapid fire'},
		
		["MAGE"] = {'frost armor', 'evocation', 'ice barrier', 'molten armor', 
					'invisibility', 'arcane power', 'icy veins'},
					
		["PALADIN"] = {'divine protection', 'seal of justice', 
					   'divine shield', 'avenging wrath'},
	    
	    ["PRIEST"] = {'dispersion'},
	    
	    ["ROGUE"] = {'evasion', 'sprint', 'slice and dice', 'vanish',
	    			 'cloak of shadows', 'adrenaline rush', 'shadow dance'},
	    
	    ["SHAMAN"] = {'lightning shield', 'water shield', 'far sight', 
	    			  'shamanistic rage', 'bloodlust', 'heroism'},
	    
	    ["WARLOCK"] = {'eye of kilrogg', 'soul swap'},
	    			   
	    ['MONK'] = {'tiger palm', 'energizing brew', 'nimble brew',
	    			'fortifying brew'},
	    
	    -- races
	    ["Troll"] = {'berserking'},
		["Dwarf"] = {'stoneform'},
		["NightElf"] = {'shadowmeld'},
		["Orc"] = {'blood fury'},
	},
	
	-- defaults for translated spells/buffs
	["translated"] = {
		["DEATHKNIGHT"] = {
			['plague strike'] = 'blood plague',
			['icy touch'] = 'frost fever',
		},
		
		["MAGE"] = {
			["scorch"] = 'improved scorch',
		},
		
		["WARLOCK"] = {
			['soul swap exhale'] = 'soul swap',
		},
		
		["MONK"] = {
			['tiger palm'] = 'tiger power',
		}
	},
	
	-- defaults for overridden spells that are shown regardless of cooldown
	["override"] = {
		["ROGUE"] = {'vendetta'},
		["MONK"] = {'tiger\'s lust', 'energizing brew', 'nimble brew'},
	},
}

local function CopyDefaults(src, dest)
	if src then
		for _, val in ipairs(src) do
			dest[val] = 1
		end
	end
end

local function CopyTranslations(src, dest)
	if src then
		for key, val in pairs(src) do
			dest[key] = {[val] = 1}
		end
	end
end

function Dominos_BuffTimes:SetDefaults(playerClass, playerRace)
	self:Print('Setting defaults for ' .. playerRace .. ' ' .. playerClass)
	CopyDefaults(self.defaults.ignored[playerClass], self.db.char.ignored)
	CopyDefaults(self.defaults.ignored[playerRace], self.db.char.ignored)
	
	CopyDefaults(self.defaults.yourbuffs[playerClass], self.db.char.yourbuffs)
	CopyDefaults(self.defaults.yourbuffs[playerRace], self.db.char.yourbuffs)
	
	CopyDefaults(self.defaults.alldebuffs[playerClass], self.db.char.alldebuffs)
	CopyDefaults(self.defaults.alldebuffs[playerRace], self.db.char.alldebuffs)
	
	CopyDefaults(self.defaults.selfbuffs[playerClass], self.db.char.selfbuffs)
	CopyDefaults(self.defaults.selfbuffs[playerRace], self.db.char.selfbuffs)
	
	CopyTranslations(self.defaults.translated[playerClass], self.db.char.translated)
	CopyTranslations(self.defaults.translated[playerRace], self.db.char.translated)
	
	CopyDefaults(self.defaults.override[playerClass], self.db.char.override)
	CopyDefaults(self.defaults.override[playerRace], self.db.char.override)
end

